@@ -86,6 +86,8 @@ class Statement(Workflow, ModelSQL, ModelView):
             'readonly': (Eval('state') != 'draft') | Eval('lines', [0]),
             },
         depends=['state', 'company'])
+    currency = fields.Function(fields.Many2One(
+            'currency.currency', "Currency"), 'on_change_with_currency')
     currency_digits = fields.Function(fields.Integer('Currency Digits'),
         'on_change_with_currency_digits')
     date = fields.Date('Date', required=True, select=True)
@@ -123,7 +125,7 @@ class Statement(Workflow, ModelSQL, ModelView):
     state = fields.Selection([
             ('draft', "Draft"),
             ('validated', "Validated"),
-            ('cancel', "Canceled"),
+            ('cancelled', "Cancelled"),
             ('posted', "Posted"),
             ], "State", readonly=True, select=True)
     validation = fields.Function(fields.Char('Validation'),
@@ -142,14 +144,14 @@ class Statement(Workflow, ModelSQL, ModelView):
         cls._order[0] = ('id', 'DESC')
         cls._transitions |= set((
                 ('draft', 'validated'),
-                ('draft', 'cancel'),
+                ('draft', 'cancelled'),
                 ('validated', 'posted'),
-                ('validated', 'cancel'),
-                ('cancel', 'draft'),
+                ('validated', 'cancelled'),
+                ('cancelled', 'draft'),
                 ))
         cls._buttons.update({
                 'draft': {
-                    'invisible': Eval('state') != 'cancel',
+                    'invisible': Eval('state') != 'cancelled',
                     'depends': ['state'],
                     },
                 'validate_statement': {
@@ -165,7 +167,7 @@ class Statement(Workflow, ModelSQL, ModelView):
                     'depends': ['state'],
                     },
                 'reconcile': {
-                    'invisible': Eval('state').in_(['draft', 'cancel']),
+                    'invisible': Eval('state').in_(['draft', 'cancelled']),
                     'readonly': ~Eval('to_reconcile'),
                     'depends': ['state', 'to_reconcile'],
                     },
@@ -193,6 +195,11 @@ class Statement(Workflow, ModelSQL, ModelView):
                 [sql_table.id.cast(cls.name.sql_type().base)],
                 where=sql_table.name == Null))
 
+        # Migration from 5.6: rename state cancel to cancelled
+        cursor.execute(*sql_table.update(
+                [sql_table.state], ['cancelled'],
+                where=sql_table.state == 'cancel'))
+
     @staticmethod
     def default_company():
         return Transaction().context.get('company')
@@ -231,6 +238,11 @@ class Statement(Workflow, ModelSQL, ModelView):
         statement, = statements
         self.start_balance = statement.end_balance
 
+    @fields.depends('journal')
+    def on_change_with_currency(self, name=None):
+        if self.journal:
+            return self.journal.currency.id
+
     @fields.depends('journal')
     def on_change_with_currency_digits(self, name=None):
         if self.journal:
@@ -412,7 +424,7 @@ class Statement(Workflow, ModelSQL, ModelView):
     @classmethod
     def view_attributes(cls):
         return [
-            ('/tree', 'visual', If(Eval('state') == 'cancel', 'muted', '')),
+            ('/tree', 'visual', If(Eval('state') == 'cancelled', 'muted', '')),
             ]
 
     @classmethod
@@ -420,7 +432,7 @@ class Statement(Workflow, ModelSQL, ModelView):
         # Cancel before delete
         cls.cancel(statements)
         for statement in statements:
-            if statement.state != 'cancel':
+            if statement.state != 'cancelled':
                 raise AccessError(
                     gettext('account_statement.msg_statement_delete_cancel',
                         statement=statement.rec_name))
@@ -631,7 +643,7 @@ class Statement(Workflow, ModelSQL, ModelView):
 
     @classmethod
     @ModelView.button
-    @Workflow.transition('cancel')
+    @Workflow.transition('cancelled')
     def cancel(cls, statements):
         StatementLine = Pool().get('account.statement.line')
 
@@ -662,9 +674,12 @@ def origin_mixin(_states, _depends):
             "Date", required=True, states=_states, depends=_depends)
         amount = fields.Numeric(
             "Amount", required=True,
-            digits=(16, Eval('_parent_statement', {})
-                .get('currency_digits', 2)),
-            states=_states, depends=_depends)
+            digits=(16, Eval('currency_digits', 2)),
+            states=_states, depends=_depends + ['currency_digits'])
+        currency = fields.Function(fields.Many2One(
+                'currency.currency', "Currency"), 'on_change_with_currency')
+        currency_digits = fields.Function(fields.Integer(
+                "Currency Digits"), 'on_change_with_currency_digits')
         party = fields.Many2One(
             'party.party', "Party", states=_states, depends=_depends)
         account = fields.Many2One(
@@ -701,6 +716,16 @@ def origin_mixin(_states, _depends):
         def search_company(cls, name, clause):
             return [('statement.' + clause[0],) + tuple(clause[1:])]
 
+        @fields.depends('statement', '_parent_statement.journal')
+        def on_change_with_currency(self, name=None):
+            if self.statement and self.statement.journal:
+                return self.statement.journal.currency.id
+
+        @fields.depends('statement', '_parent_statement.journal')
+        def on_change_with_currency_digits(self, name=None):
+            if self.statement and self.statement.journal:
+                return self.statement.journal.currency.digits
+
     return Mixin
 
 
@@ -1163,11 +1188,8 @@ class ReconcileStatement(Wizard):
     start = StateAction('account.act_reconcile')
 
     def do_start(self, action):
-        pool = Pool()
-        Statement = pool.get('account.statement')
-        statements = Statement.browse(Transaction().context['active_ids'])
-        lines = sum(([int(l) for l in s.lines_to_reconcile]
-                for s in statements), [])
+        lines = sum(
+            ([int(l) for l in s.lines_to_reconcile] for s in self.records), [])
         return action, {
             'model': 'account.move.line',
             'ids': lines,
